@@ -13,9 +13,9 @@
 #
 #
 carb<-
-function(flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T"){
+function(flag, var1, var2, S=35, T=25, P=0, Pt=0, Sit=0, k1k2='x', kf='x', ks="d", pHscale="T", b="l10"){
 RES <- data.frame()
-n <- max(length(var1), length(var2), length(S), length(T), length(P), length(Pt), length(Sit), length(k1k2), length(kf), length(pHscale), length(ks))
+n <- max(length(var1), length(var2), length(S), length(T), length(P), length(Pt), length(Sit), length(k1k2), length(kf), length(pHscale), length(ks), length(b))
 if(length(flag)!=n){ flag <- rep(flag[1],n)}
 if(length(var1)!=n){ var1 <- rep(var1[1],n)}
 if(length(var2)!=n){ var2 <- rep(var2[1],n)}
@@ -28,8 +28,9 @@ if(length(k1k2)!=n){ k1k2 <- rep(k1k2[1],n)}
 if(length(kf)!=n){ kf <- rep(kf[1],n)}
 if(length(ks)!=n){ ks <- rep(ks[1],n)}
 if(length(pHscale)!=n){pHscale <- rep(pHscale[1],n)}
+if(length(b)!=n){ b <- rep(b[1],n)}
 
-df <- data.frame(flag, var1, var2, S, T, P, Pt, Sit, pHscale)
+df <- data.frame(flag, var1, var2, S, T, P, Pt, Sit, pHscale, b)
 
 
 ##BOUCLE
@@ -43,6 +44,7 @@ for(i in (1:nrow(df))) {
   Pt <- as.numeric(df[i,7])
   Sit <- as.numeric(df[i,8])
   pHscale <- as.character(df[i,9])
+  b <- as.character(df[i,10])
 
 res <- rep(NA, 14)
 
@@ -62,7 +64,7 @@ cl3 = Cl^(1/3);
 ION = 0.00147 + 0.03592 * Cl + 0.000068 * Cl * Cl;   # ionic strength
 iom0 = 19.924*S/(1000-1.005*S);
 ST = 0.14/96.062/1.80655*S;   # (mol/kg soln) total sulfate
-bor = (416.*(S/35.))* 1e-6;   # (mol/kg), DOE94 boron total
+bor = bor(S=S , b=b);   # (mol/kg), DOE94 boron total
 fluo = (7*(S/35))*1e-5        # (mol/kg), DOE94 fluoride total
 
 #---------------------------------------------------------------------
